/*** ezt.h:begin ***/

#ifndef _EZT_H
#define _EZT_H 1

#define _EZT_VER 2.0

#ifndef EZT_MIN_TCL_VER
# define EZT_MIN_TCL_VER "8.6"
#endif

#ifdef EZT_ERRORPRINTF
# include <stdarg.h>
# include <stdio.h>
#endif

#ifdef EZT_REPORTERROR
# include <stdarg.h>
#endif

#include "ezt_tj.h"

#define COMBIEN(Z) ((int) (sizeof(Z) / sizeof(Z[0])))

#ifdef FOR_TCL
typedef struct EztCmd {
	const char *name;
	Tcl_ObjCmdProc *proc;
#ifdef EZT_COMMAND_CLIENTDATA
	ClientData clientData;
#endif
} Ezt_Cmd;
#endif

#define Ezt_NewStr(S) Ezt_NewString((S),-1)

#ifdef EZT_REPORTERROR
static int Ezt_ReportError (Ezt_Interp *interp, ...);
#define rerr(msg)  Ezt_ReportError(interp, (msg), (char*) NULL)
# ifdef FOR_TCL
#  define rperr(msg) Ezt_ReportError(interp, (msg), Tcl_PosixError(interp), (char*) NULL)
# endif
#define NAGFO(str) Ezt_ReportError(interp, "no argument given for ", (str), " option", (char*) NULL)
#endif

#ifdef EZT_ERRORPRINTF
static int Ezt_ErrorPrintf (Ezt_Interp *interp, const char *format, ...);
# define rerrf(fmt,...) Ezt_ErrorPrintf(interp, (fmt), __VA_ARGS__)
#endif

#ifdef EZT_EZTWRONGNUMARGS
static int Ezt_EztWrongNumArgs (Ezt_Interp *interp, int objc, Ezt_Obj *const objv[], const char *message);
#endif

#ifdef EZT_EZTWRONGNUMARGS
# define Ezt_WrongNumArgs Ezt_EztWrongNumArgs
#else
# define Ezt_WrongNumArgs Ezt_TJWrongNumArgs
#endif

#ifdef EZT_EXT_INIT
static int EZT_EXT_INIT (Ezt_Interp *interp);
#endif

#ifdef EZT_PKGINIT
static int EZT_PKGINIT (Ezt_Interp *interp, const char *namespace);
#endif

#ifdef EZT_TIMEVAL2DBL
static Ezt_Obj * Ezt_TimevalToDoubleObj (struct timeval *tv);
#endif

#ifdef EZT_STR2TIMEVAL
static int Ezt_StrToTimeval (Ezt_Interp *interp, const char *str, struct timeval *tv); /* Needs dbl2timeval */
# ifndef EZT_DBL2TIMEVAL
#  define EZT_DBL2TIMEVAL 1
# endif
#endif

#ifdef EZT_DBL2TIMEVAL
static int Ezt_DoubleObjToTimeval (Ezt_Interp *interp, Ezt_Obj *obj, struct timeval *tv);
#endif

#ifdef FOR_JIM
# ifdef EZT_JIM_GETINT
static int Ezt_GetIntFromJimObj (Jim_Interp *interp, Jim_Obj *objPtr, int *intPtr);
# endif
#endif


/* Junkpile */

#ifdef EZT_ASSOCDATA_KEY

typedef struct EztJunk {
	Ezt_Obj *pile;
	unsigned long counter;
} EztJunk;

static EztJunk * Ezt_GetJunk (Ezt_Interp *interp);

static int Ezt_PutIt (Ezt_Interp *interp, Ezt_Obj *what, Ezt_Obj *val);
static void Ezt_RemoveIt (Ezt_Interp *interp, Ezt_Obj *what);
static Ezt_Obj *Ezt_GetIt (Ezt_Interp *interp, Ezt_Obj *what);
static unsigned long Ezt_NextCounter (Ezt_Interp *interp);

# ifdef EZT_FUNC_JUNKPILEASLIST
static Ezt_Obj * Ezt_JunkPileAsList (Ezt_Interp *interp);
# endif

#endif /* EZT_ASSOCDATA_KEY */

#ifdef EZT_EAGAIN_EWOULDBLOCK
/*
 * Make sure that both EAGAIN and EWOULDBLOCK are defined.
 * This does not compile on systems where neither is defined.
 * We want both defined so that we can test safely for both.
 * In the code we still have to test for both because there may
 * be systems on which both are defined and have different values.
 */
#if ((!defined(EWOULDBLOCK)) && (defined(EAGAIN)))
#   define EWOULDBLOCK EAGAIN
#endif
#if ((!defined(EAGAIN)) && (defined(EWOULDBLOCK)))
#   define EAGAIN EWOULDBLOCK
#endif
#if ((!defined(EAGAIN)) && (!defined(EWOULDBLOCK)))
#error one of EWOULDBLOCK or EAGAIN must be defined
#endif
#endif /* EZT_EAGAIN_EWOULDBLOCK */

#ifdef EZT_INT2PTR_PTR2INT
/*
 * Macros used to cast between pointers and integers
 * (e.g. when storing an int * in ClientData).
 * For compiler warnings about
 * "cast to/from pointer from/to integer of different size".
 */
#if !defined(INT2PTR) && !defined(PTR2INT)
#   if defined(HAVE_INTPTR_T) || defined(intptr_t)
#	define INT2PTR(p) ((void *)(intptr_t)(p))
#	define PTR2INT(p) ((int)(intptr_t)(p))
#   else
#	define INT2PTR(p) ((void *)(p))
#	define PTR2INT(p) ((int)(p))
#   endif
#endif
#if !defined(UINT2PTR) && !defined(PTR2UINT)
#   if defined(HAVE_UINTPTR_T) || defined(uintptr_t)
#	define UINT2PTR(p) ((void *)(uintptr_t)(p))
#	define PTR2UINT(p) ((unsigned int)(uintptr_t)(p))
#   else
#	define UINT2PTR(p) ((void *)(p))
#	define PTR2UINT(p) ((unsigned int)(p))
#   endif
#endif
#endif /* EZT_INT2PTR_PTR2INT */

#endif /* _EZT_H */

/*** ezt.h:end ***/
